==> zio-aws-mediapackage_2.13-5.17.125.1-sources.jar: zio/aws/mediapackage/model/DeleteOriginEndpointRequest.scala <==
package zio.aws.mediapackage.model
import zio.aws.mediapackage.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DeleteOriginEndpointRequest(id: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediapackage.model.DeleteOriginEndpointRequest = {
    import DeleteOriginEndpointRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediapackage.model.DeleteOriginEndpointRequest
      .builder()
      .id(__string.unwrap(id): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.mediapackage.model.DeleteOriginEndpointRequest.ReadOnly =
    zio.aws.mediapackage.model.DeleteOriginEndpointRequest.wrap(buildAwsValue())
}
object DeleteOriginEndpointRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediapackage.model.DeleteOriginEndpointRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediapackage.model.DeleteOriginEndpointRequest =
      zio.aws.mediapackage.model.DeleteOriginEndpointRequest(id)
    def id: __string
    def getId: ZIO[Any, Nothing, __string] = ZIO.succeed(id)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediapackage.model.DeleteOriginEndpointRequest
  ) extends zio.aws.mediapackage.model.DeleteOriginEndpointRequest.ReadOnly {
    override val id: __string =
      zio.aws.mediapackage.model.primitives.__string(impl.id())
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediapackage.model.DeleteOriginEndpointRequest
  ): zio.aws.mediapackage.model.DeleteOriginEndpointRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-mediapackage_2.13-5.17.170.1-sources.jar: zio/aws/mediapackage/model/DeleteOriginEndpointRequest.scala <==
package zio.aws.mediapackage.model
import zio.aws.mediapackage.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DeleteOriginEndpointRequest(id: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediapackage.model.DeleteOriginEndpointRequest = {
    import DeleteOriginEndpointRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediapackage.model.DeleteOriginEndpointRequest
      .builder()
      .id(id: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.mediapackage.model.DeleteOriginEndpointRequest.ReadOnly =
    zio.aws.mediapackage.model.DeleteOriginEndpointRequest.wrap(buildAwsValue())
}
object DeleteOriginEndpointRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediapackage.model.DeleteOriginEndpointRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediapackage.model.DeleteOriginEndpointRequest =
      zio.aws.mediapackage.model.DeleteOriginEndpointRequest(id)
    def id: __string
    def getId: ZIO[Any, Nothing, __string] = ZIO.succeed(id)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediapackage.model.DeleteOriginEndpointRequest
  ) extends zio.aws.mediapackage.model.DeleteOriginEndpointRequest.ReadOnly {
    override val id: __string = impl.id(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediapackage.model.DeleteOriginEndpointRequest
  ): zio.aws.mediapackage.model.DeleteOriginEndpointRequest.ReadOnly =
    new Wrapper(impl)
}
